@@ -14,13 +14,22 @@
 #'   min annd max wavelengths (nm)
 #' @param pc.out logical, if TRUE use percents instead of fraction of one
 #' @param label.qty character string giving the type of summary quantity to use
-#'   for labels
+#'   for labels, one of "mean", "total", "contribution", and "relative".
+#' @param span a peak is defined as an element in a sequence which is greater
+#'   than all other elements within a window of width span centered at that
+#'   element.
 #' @param annotations a character vector
 #' @param norm numeric normalization wavelength (nm) or character string "max"
 #'   for normalization at the wavelength of highest peak.
 #' @param text.size numeric size of text in the plot decorations.
+#' @param idfactor character Name of an index column in data holding a
+#'   \code{factor} with each spectrum in a long-form multispectrum object
+#'   corresponding to a distinct spectrum. If \code{idfactor=NULL} the name of
+#'   the factor is retrieved from metadata or if no metadata found, the
+#'   default "spct.idx" is tried.
+#' @param ylim numeric y axis limits,
 #' @param na.rm logical.
-#' @param ... other arguments
+#' @param ... currently ignored.
 #'
 #' @return a \code{ggplot} object.
 #'
@@ -31,21 +40,29 @@ cps_plot <- function(spct,
                      range,
                      pc.out,
                      label.qty,
+                     span,
                      annotations,
                      norm,
                      text.size,
+                     idfactor,
+                     ylim,
                      na.rm,
                      ...) {
   if (!is.cps_spct(spct)) {
     stop("cps_plot() can only plot response_spct objects.")
   }
+  if (is.null(ylim) || !is.numeric(ylim)) {
+    ylim <- rep(NA_real_, 2L)
+  }
   if (!is.null(range)) {
-    trim_wl(spct, range = range, byref = TRUE)
+    spct <- trim_wl(spct, range = range)
   }
   if (!is.null(w.band)) {
-    trim_wl(w.band, range = range(spct))
+    w.band <- trim_wl(w.band, range = range(spct))
   }
   cps.cols <- names(spct)[grep("^cps", names(spct))]
+  num.cps.cols <- length(cps.cols)
+  stopifnot(num.cps.cols == 1L || getMultipleWl(spct) <= 1L)
   #  other.cols <- setdiff(names(x), cps.cols)
   if (is.null(norm)) {
     # we will use the original data
@@ -94,19 +111,47 @@ cps_plot <- function(spct,
     cps.label <- ""
   }
 
-  spct <- reshape2::melt(spct,
-                         id.vars = "w.length",
-                         measure.vars = cps.cols,
-                         variable.name = "scan",
-                         value.name = "cps")
-  setCpsSpct(spct, multiple.wl = length(cps.cols))
-  y.max <- max(c(spct[["cps"]], 0), na.rm = TRUE)
-  y.min <- min(c(spct[["cps"]], 0), na.rm = TRUE)
-  plot <- ggplot(spct) + aes_(linetype = ~scan) +
-    scale_fill_identity() + scale_color_identity()
+  if (num.cps.cols > 1L) {
+    spct <- tidyr::gather(spct,
+                          .dots = cps.cols,
+                          key = "scan",
+                          value = "cps")
+    setCpsSpct(spct, multiple.wl = length(cps.cols))
+    plot <- ggplot(spct, aes_(x = ~w.length, y = ~cps, linetype = ~scan))
+  } else {
+    plot <- ggplot(spct, aes_(x = ~w.length, y = ~cps))
+    temp <- find_idfactor(spct = spct,
+                          idfactor = idfactor,
+                          annotations = annotations)
+    plot <- plot + temp$ggplot_comp
+    annotations <- temp$annotations
+  }
+
+  y.min <- ifelse(!is.na(ylim[1]),
+                  ylim[1],
+                  min(c(spct[["cps"]], 0), na.rm = TRUE))
+  y.max <- ifelse(!is.na(ylim[2]),
+                  ylim[2],
+                  max(c(spct[["cps"]], 0), na.rm = TRUE))
+
+  # We want data plotted on top of the boundary lines
+  if ("boundaries" %in% annotations) {
+    if (y.min < (-0.01 * y.max)) {
+      plot <- plot + geom_hline(yintercept = 0, linetype = "dashed", colour = "red")
+    } else {
+      plot <- plot + geom_hline(yintercept = 0, linetype = "dashed", colour = "black")
+    }
+  }
+
   plot <- plot + geom_line(na.rm = na.rm)
   plot <- plot + labs(x = "Wavelength (nm)", y = s.cps.label)
 
+  if (length(annotations) == 1 && annotations == "") {
+    return(plot)
+  }
+
+  plot <- plot + scale_fill_identity() + scale_color_identity()
+
   plot <- plot + decoration(w.band = w.band,
                             y.max = y.max,
                             y.min = y.min,
@@ -114,20 +159,22 @@ cps_plot <- function(spct,
                             x.min = min(spct),
                             annotations = annotations,
                             label.qty = label.qty,
+                            span = span,
                             summary.label = cps.label,
                             text.size = text.size,
                             na.rm = TRUE)
 
   if (!is.null(annotations) &&
-      length(intersect(c("boxes", "segments", "labels", "summaries", "colour.guide"), annotations)) > 0L) {
+      length(intersect(c("boxes", "segments", "labels", "summaries", "colour.guide", "reserve.space"), annotations)) > 0L) {
     y.limits <- c(y.min, y.max * 1.25)
-    x.limits <- c(min(spct) - spread(spct) * 0.025, NA) # NA needed because of rounding errors
+    x.limits <- c(min(spct) - wl_expanse(spct) * 0.025, NA) # NA needed because of rounding errors
   } else {
     y.limits <- c(y.min, y.max)
     x.limits <- range(spct)
   }
+
   plot <- plot + scale_y_continuous(limits = y.limits)
-  plot + scale_x_continuous(limits = x.limits)
+  plot + scale_x_continuous(limits = x.limits, breaks = scales::pretty_breaks(n = 7))
 
 }
 
@@ -139,18 +186,31 @@ cps_plot <- function(spct,
 #' @note Note that scales are expanded so as to make space for the annotations.
 #'   The object returned is a ggplot objects, and can be further manipulated.
 #'
-#' @param x a cps_spct object
-#' @param ... other arguments passed along, such as \code{label.qty}
-#' @param w.band a single waveband object or a list of waveband objects
+#' @param x a cps_spct object.
+#' @param ... in the case of collections of spectra, additional arguments passed
+#'   to the plot methods for individual spectra, otherwise currently ignored.
+##' @param w.band a single waveband object or a list of waveband objects.
 #' @param range an R object on which range() returns a vector of length 2, with
-#'   min annd max wavelengths (nm)
-#' @param unit.out character IGNORED
+#'   min annd max wavelengths (nm).
+#' @param unit.out character IGNORED.
 #' @param pc.out logical, if TRUE use percents instead of fraction of one
-#' @param label.qty character IGNORED
-#' @param annotations a character vector ("summaries" is ignored)
+#' @param label.qty character string giving the type of summary quantity to use
+#'   for labels, one of "mean", "total", "contribution", and "relative".
+#' @param span a peak is defined as an element in a sequence which is greater
+#'   than all other elements within a window of width span centered at that
+#'   element.
+#' @param annotations a character vector ("summaries" is ignored).
+#' @param time.format character Format as accepted by \code{\link[base]{strptime}}.
+#' @param tz character Time zone to use for title and/or subtitle.
 #' @param norm numeric normalization wavelength (nm) or character string "max"
 #'   for normalization at the wavelength of highest peak.
 #' @param text.size numeric size of text in the plot decorations.
+#' @param idfactor character Name of an index column in data holding a
+#'   \code{factor} with each spectrum in a long-form multispectrum object
+#'   corresponding to a distinct spectrum. If \code{idfactor=NULL} the name of
+#'   the factor is retrieved from metadata or if no metadata found, the
+#'   default "spct.idx" is tried.
+#' @param ylim numeric y axis limits,
 #' @param na.rm logical.
 #'
 #' @return a \code{ggplot} object.
@@ -168,16 +228,21 @@ plot.cps_spct <-
            range = NULL,
            unit.out = "cps",
            pc.out = FALSE,
-           label.qty = "average",
-           annotations = getOption("photobiology.plot.annotations",
-                                 default = c("boxes", "labels",
-                                             "colour.guide", "peaks")),
+           label.qty = "mean",
+           span = NULL,
+           annotations = NULL,
+           time.format = "",
+           tz = "UTC",
            norm = NULL,
            text.size = 2.5,
+           idfactor = NULL,
+           ylim = c(NA, NA),
            na.rm = TRUE) {
-    if ("color.guide" %in% annotations) {
-      annotations <- c(setdiff(annotations, "color.guide"), "colour.guide")
-    }
+    annotations.default <-
+      getOption("photobiology.plot.annotations",
+                default = c("boxes", "labels", "colour.guide", "peaks"))
+    annotations <- decode_annotations(annotations,
+                                      annotations.default)
     if (length(w.band) == 0) {
       if (is.null(range)) {
         w.band <- waveband(x)
@@ -188,17 +253,21 @@ plot.cps_spct <-
       }
     }
 
-    out.ggplot <- cps_plot(spct = x, w.band = w.band, range = range,
-                           label.qty = label.qty,
-                           pc.out = pc.out,
-                           annotations = annotations, norm = norm,
-                           text.size = text.size,
-                           na.rm = na.rm,
-                           ...)
-    if ("title" %in% annotations) {
-      out.ggplot <- out.ggplot + labs(title = deparse(substitute(x)))
-    }
-    out.ggplot
+    cps_plot(spct = x, w.band = w.band, range = range,
+             label.qty = label.qty,
+             span = span,
+             pc.out = pc.out,
+             annotations = annotations, norm = norm,
+             text.size = text.size,
+             idfactor = idfactor,
+             ylim = ylim,
+             na.rm = na.rm,
+             ...) +
+      ggtitle_spct(x = x,
+                   time.format = time.format,
+                   tz = tz,
+                   x.name = deparse(substitute(x)),
+                   annotations = annotations)
   }
 
 
