@@ -6,19 +6,28 @@
 #' @note Note that scales are expanded so as to make space for the annotations.
 #'   The object returned is a ggplot objects, and can be further manipulated.
 #'
-#' @param spct a response_spct object
-#' @param w.band list of waveband objects
+#' @param spct a response_spct object.
+#' @param w.band list of waveband objects.
 #' @param range an R object on which range() returns a vector of length 2, with
-#'   min annd max wavelengths (nm)
-#' @param pc.out logical, if TRUE use percents instead of fraction of one
+#'   min annd max wavelengths (nm).
+#' @param pc.out logical, if TRUE use percents instead of fraction of one.
 #' @param label.qty character string giving the type of summary quantity to use
-#'   for labels
-#' @param annotations a character vector
+#'   for labels, one of "mean", "total", "contribution", and "relative".
+#' @param span a peak is defined as an element in a sequence which is greater
+#'   than all other elements within a window of width span centered at that
+#'   element.
+#' @param annotations a character vector.
 #' @param norm numeric normalization wavelength (nm) or character string "max"
 #'   for normalization at the wavelength of highest peak.
 #' @param text.size numeric size of text in the plot decorations.
+#' @param idfactor character Name of an index column in data holding a
+#'   \code{factor} with each spectrum in a long-form multispectrum object
+#'   corresponding to a distinct spectrum. If \code{idfactor=NULL} the name of
+#'   the factor is retrieved from metadata or if no metadata found, the
+#'   default "spct.idx" is tried.
 #' @param na.rm logical.
-#' @param ... other arguments passed to e_response()
+#' @param ylim numeric y axis limits,
+#' @param ... currently ignored.
 #'
 #' @return a \code{ggplot} object.
 #'
@@ -29,20 +38,26 @@ e_rsp_plot <- function(spct,
                        range,
                        pc.out,
                        label.qty,
+                       span,
                        annotations,
                        norm,
                        text.size,
+                       idfactor,
+                       ylim,
                        na.rm,
                        ...) {
   if (!is.response_spct(spct)) {
     stop("e_Rsp_plot() can only plot response_spct objects.")
   }
+  if (is.null(ylim) || !is.numeric(ylim)) {
+    ylim <- rep(NA_real_, 2L)
+  }
   q2e(spct, action="replace", byref=TRUE)
   if (!is.null(range)) {
-    trim_wl(spct, range = range, byref = TRUE)
+    spct <- trim_wl(spct, range = range)
   }
   if (!is.null(w.band)) {
-    trim_wl(w.band, range = range(spct))
+    w.band <- trim_wl(w.band, range = range(spct))
   }
 
   exposure.label <- NA
@@ -138,8 +153,13 @@ e_rsp_plot <- function(spct,
     rsp.label.avg  <- bquote(atop(bar(R[E](lambda)/R[E](lambda = norm)), (.(multiplier.label))))
   }
   spct[["s.e.response"]] <- spct[["s.e.response"]] * scale.factor
-  y.max <- max(c(spct[["s.e.response"]], 0), na.rm = TRUE)
-  y.min <- min(c(spct[["s.e.response"]], 0), na.rm = TRUE)
+
+  y.min <- ifelse(!is.na(ylim[1]),
+                  ylim[1],
+                  min(c(spct[["s.e.response"]], 0), na.rm = TRUE))
+  y.max <- ifelse(!is.na(ylim[2]),
+                  ylim[2],
+                  max(c(spct[["s.e.response"]], 0), na.rm = TRUE))
 
   if (label.qty == "total") {
     rsp.label <- "integral(R[E](lambda))"
@@ -157,11 +177,28 @@ e_rsp_plot <- function(spct,
     rsp.label <- ""
   }
 
-  plot <- ggplot(spct, aes_(~w.length, ~s.e.response)) +
-    scale_fill_identity() + scale_color_identity()
+  plot <- ggplot(spct, aes_(~w.length, ~s.e.response))
+  temp <- find_idfactor(spct = spct,
+                        idfactor = idfactor,
+                        annotations = annotations)
+  plot <- plot + temp$ggplot_comp
+  annotations <- temp$annotations
+
+  # We want data plotted on top of the boundary lines
+  # Negative response is valid!
+  if ("boundaries" %in% annotations) {
+    plot <- plot + geom_hline(yintercept = 0, linetype = "dashed", colour = "black")
+  }
+
   plot <- plot + geom_line(na.rm = na.rm)
   plot <- plot + labs(x = "Wavelength (nm)", y = s.rsp.label)
 
+  if (length(annotations) == 1 && annotations == "") {
+    return(plot)
+  }
+
+  plot <- plot + scale_fill_identity() + scale_color_identity()
+
   plot <- plot + decoration(w.band = w.band,
                             y.max = y.max,
                             y.min = y.min,
@@ -169,6 +206,7 @@ e_rsp_plot <- function(spct,
                             x.min = min(spct),
                             annotations = annotations,
                             label.qty = label.qty,
+                            span = span,
                             summary.label = rsp.label,
                             text.size = text.size,
                             na.rm = TRUE)
@@ -186,20 +224,21 @@ e_rsp_plot <- function(spct,
 
   if (!is.null(annotations) &&
       length(intersect(c("boxes", "segments", "labels", "summaries",
-                         "colour.guide"), annotations)) > 0L) {
+                         "colour.guide", "reserve.space"), annotations)) > 0L) {
     y.limits <- c(y.min, y.max * 1.25)
-    x.limits <- c(min(spct) - spread(spct) * 0.025, NA) # NA needed because of rounding errors
+    x.limits <- c(min(spct) - wl_expanse(spct) * 0.025, NA) # NA needed because of rounding errors
   } else {
     y.limits <- c(y.min, y.max)
     x.limits <- range(spct)
   }
+
   if (abs(y.min) < 5e-2 && (abs(y.max - 1) < 5.e-2)) {
     plot <- plot +
       scale_y_continuous(breaks = c(0, 0.25, 0.5, 0.75, 1), limits = y.limits)
   } else {
     plot <- plot + scale_y_continuous(limits = y.limits)
   }
-  plot + scale_x_continuous(limits = x.limits)
+  plot + scale_x_continuous(limits = x.limits, breaks = scales::pretty_breaks(n = 7))
 }
 
 #' Plot a response spectrum.
@@ -210,19 +249,28 @@ e_rsp_plot <- function(spct,
 #' @note Note that scales are expanded so as to make space for the annotations.
 #'   The object returned is a ggplot objects, and can be further manipulated.
 #'
-#' @param spct a response_spct object
-#' @param w.band list of waveband objects
+#' @param spct a response_spct object.
+#' @param w.band list of waveband objects.
 #' @param range an R object on which range() returns a vector of length 2, with
-#'   min annd max wavelengths (nm)
-#' @param pc.out logical, if TRUE use percents instead of fraction of one
+#'   min annd max wavelengths (nm).
+#' @param pc.out logical, if TRUE use percents instead of fraction of one.
 #' @param label.qty character string giving the type of summary quantity to use
-#'   for labels
-#' @param annotations a character vector
+#'   for labels, one of "mean", "total", "contribution", and "relative".
+#' @param span a peak is defined as an element in a sequence which is greater
+#'   than all other elements within a window of width span centered at that
+#'   element.
+#' @param annotations a character vector.
 #' @param norm numeric normalization wavelength (nm) or character string "max"
 #'   for normalization at the wavelength of highest peak.
 #' @param text.size numeric size of text in the plot decorations.
+#' @param idfactor character Name of an index column in data holding a
+#'   \code{factor} with each spectrum in a long-form multispectrum object
+#'   corresponding to a distinct spectrum. If \code{idfactor=NULL} the name of
+#'   the factor is retrieved from metadata or if no metadata found, the
+#'   default "spct.idx" is tried.
+#' @param ylim numeric y axis limits,
 #' @param na.rm logical.
-#' @param ... other arguments passed to q_response()
+#' @param ... currently ignored.
 #'
 #' @return a \code{ggplot} object.
 #'
@@ -233,20 +281,26 @@ q_rsp_plot <- function(spct,
                        range,
                        pc.out,
                        label.qty,
+                       span,
                        annotations,
                        norm,
                        text.size,
+                       idfactor,
+                       ylim,
                        na.rm,
                        ...) {
   if (!is.response_spct(spct)) {
     stop("q_Rsp_plot() can only plot response_spct objects.")
   }
+  if (is.null(ylim) || !is.numeric(ylim)) {
+    ylim <- rep(NA_real_, 2L)
+  }
   e2q(spct, action="replace", byref=TRUE)
   if (!is.null(range)) {
-    trim_wl(spct, range = range, byref = TRUE)
+    spct <- trim_wl(spct, range = range)
   }
   if (!is.null(w.band)) {
-    trim_wl(w.band, range = range(spct))
+    w.band <- trim_wl(w.band, range = range(spct))
   }
 
   exposure.label <- NA
@@ -342,8 +396,13 @@ q_rsp_plot <- function(spct,
     rsp.label.avg  <- bquote(atop(bar(R[Q](lambda)/R[Q](lambda = norm)), (.(multiplier.label))))
   }
   spct[["s.q.response"]] <- spct[["s.q.response"]] * scale.factor
-  y.max <- max(c(spct[["s.q.response"]], 0), na.rm = TRUE)
-  y.min <- min(c(spct[["s.q.response"]], 0), na.rm = TRUE)
+
+  y.min <- ifelse(!is.na(ylim[1]),
+                  ylim[1],
+                  min(c(spct[["s.q.response"]], 0), na.rm = TRUE))
+  y.max <- ifelse(!is.na(ylim[2]),
+                  ylim[2],
+                  max(c(spct[["s.q.response"]], 0), na.rm = TRUE))
 
   if (label.qty == "total") {
     rsp.label <- "integral(R[Q](lambda))"
@@ -361,10 +420,28 @@ q_rsp_plot <- function(spct,
     rsp.label <- ""
   }
 
-  plot <- ggplot(spct, aes_(~w.length, ~s.q.response)) +
-    scale_fill_identity() + scale_color_identity()
+  plot <- ggplot(spct, aes_(x = ~w.length, y = ~s.q.response))
+  temp <- find_idfactor(spct = spct,
+                        idfactor = idfactor,
+                        annotations = annotations)
+  plot <- plot + temp$ggplot_comp
+  annotations <- temp$annotations
+
+  # We want data plotted on top of the boundary lines
+  # Negative response is valid!
+  if ("boundaries" %in% annotations) {
+    plot <- plot + geom_hline(yintercept = 0, linetype = "dashed", colour = "black")
+  }
+
   plot <- plot + geom_line(na.rm = na.rm)
   plot <- plot + labs(x = "Wavelength (nm)", y = s.rsp.label)
+
+  if (length(annotations) == 1 && annotations == "") {
+    return(plot)
+  }
+
+  plot <- plot + scale_fill_identity() + scale_color_identity()
+
   plot <- plot + decoration(w.band = w.band,
                             y.max = y.max,
                             y.min = y.min,
@@ -372,6 +449,7 @@ q_rsp_plot <- function(spct,
                             x.min = min(spct),
                             annotations = annotations,
                             label.qty = label.qty,
+                            span = span,
                             summary.label = rsp.label,
                             text.size = text.size,
                             na.rm = TRUE)
@@ -389,44 +467,59 @@ q_rsp_plot <- function(spct,
 
   if (!is.null(annotations) &&
       length(intersect(c("boxes", "segments", "labels", "summaries",
-                         "colour.guide"), annotations)) > 0L) {
+                         "colour.guide", "reserve.space"), annotations)) > 0L) {
     y.limits <- c(y.min, y.max * 1.25)
-    x.limits <- c(min(spct) - spread(spct) * 0.025, NA) # NA needed because of rounding errors
+    x.limits <- c(min(spct) - wl_expanse(spct) * 0.025, NA) # NA needed because of rounding errors
   } else {
     y.limits <- c(y.min, y.max)
     x.limits <- range(spct)
   }
-  if (abs(y.min) < 5e-2 && (abs(y.max - 1) < 5.e-2)) {
+
+  if ((abs(y.min) < 5e-2) && (abs(y.max - 1) < 5.e-2)) {
     plot <- plot +
       scale_y_continuous(breaks = c(0, 0.25, 0.5, 0.75, 1), limits = y.limits)
   } else {
     plot <- plot + scale_y_continuous(limits = y.limits)
   }
-  plot + scale_x_continuous(limits = x.limits)
+  plot + scale_x_continuous(limits = x.limits, breaks = scales::pretty_breaks(n = 7))
 }
 
-#' Plot method for response spectra.
+#' Plot methods for response spectra.
 #'
-#' This function returns a ggplot object with an annotated plot of a
-#' response_spct object.
+#' These methods return a ggplot object with an annotated plot of a
+#' response_spct object or of the spectra contained in a response_mspct object.
 #'
 #' @note Note that scales are expanded so as to make space for the annotations.
-#'   The object returned is a ggplot objects, and can be further manipulated.
+#'   The object returned is a ggplot object, and can be further manipulated and
+#'   added to.
 #'
-#' @param x a response_spct object
-#' @param ... other arguments passed along, such as \code{label.qty}
-#' @param w.band a single waveband object or a list of waveband objects
+#' @param x a response_spct object or a response_mspct object.
+#' @param ... in the case of collections of spectra, additional arguments passed
+#'   to the plot methods for individual spectra, otherwise currently ignored.
+#' @param w.band a single waveband object or a list of waveband objects.
 #' @param range an R object on which range() returns a vector of length 2, with
-#'   min annd max wavelengths (nm)
+#'   min annd max wavelengths (nm).
 #' @param unit.out character string indicating type of radiation units to use
-#'   for plotting: "photon" or its synomin "quantum", or "energy"
+#'   for plotting: "photon" or its synomin "quantum", or "energy".
 #' @param pc.out logical, if TRUE use percents instead of fraction of one
 #' @param label.qty character string giving the type of summary quantity to use
-#'   for labels
-#' @param annotations a character vector
+#'   for labels, one of "mean", "total", "contribution", and "relative".
+#' @param span a peak is defined as an element in a sequence which is greater
+#'   than all other elements within a window of width span centered at that
+#'   element.
+#' @param annotations a character vector.
+#' @param time.format character Format as accepted by
+#'   \code{\link[base]{strptime}}.
+#' @param tz character Time zone to use for title and/or subtitle.
 #' @param norm numeric normalization wavelength (nm) or character string "max"
 #'   for normalization at the wavelength of highest peak.
 #' @param text.size numeric size of text in the plot decorations.
+#' @param idfactor character Name of an index column in data holding a
+#'   \code{factor} with each spectrum in a long-form multispectrum object
+#'   corresponding to a distinct spectrum. If \code{idfactor=NULL} the name of
+#'   the factor is retrieved from metadata or if no metadata found, the
+#'   default "spct.idx" is tried.
+#' @param ylim numeric y axis limits,
 #' @param na.rm logical.
 #'
 #' @return a \code{ggplot} object.
@@ -451,15 +544,20 @@ plot.response_spct <-
            unit.out = getOption("photobiology.radiation.unit", default="energy"),
            pc.out = FALSE,
            label.qty = NULL,
-           annotations = getOption("photobiology.plot.annotations",
-                                   default = c("boxes", "labels", "summaries",
-                                               "colour.guide", "peaks")),
+           span = NULL,
+           annotations = NULL,
+           time.format = "",
+           tz = "UTC",
            norm = "max",
            text.size = 2.5,
+           idfactor = NULL,
+           ylim = c(NA, NA),
            na.rm = TRUE) {
-    if ("color.guide" %in% annotations) {
-      annotations <- c(setdiff(annotations, "color.guide"), "colour.guide")
-    }
+    annotations.default <-
+      getOption("photobiology.plot.annotations",
+                default = c("boxes", "labels", "summaries", "colour.guide", "peaks"))
+    annotations <- decode_annotations(annotations,
+                                      annotations.default)
     if (is.null(label.qty)) {
       if (is_normalized(x) || is_scaled(x)) {
         label.qty = "contribution"
@@ -477,27 +575,54 @@ plot.response_spct <-
       }
     }
 
-    if (unit.out=="photon" || unit.out=="quantum") {
-      out.ggplot <- q_rsp_plot(spct=x, w.band=w.band, range=range,
-                               pc.out=pc.out, label.qty=label.qty,
-                               annotations=annotations, norm = norm,
+    if (unit.out=="photon" || unit.out == "quantum") {
+      out.ggplot <- q_rsp_plot(spct = x,
+                               w.band = w.band,
+                               range = range,
+                               pc.out = pc.out,
+                               label.qty = label.qty,
+                               span = span,
+                               annotations = annotations,
+                               norm = norm,
                                text.size = text.size,
+                               idfactor = idfactor,
+                               ylim = ylim,
                                na.rm = na.rm,
                                ...)
     } else if (unit.out=="energy") {
-      out.ggplot <- e_rsp_plot(spct=x, w.band=w.band, range=range,
-                               pc.out=pc.out, label.qty=label.qty,
-                               annotations=annotations, norm = norm,
+      out.ggplot <- e_rsp_plot(spct = x,
+                               w.band = w.band,
+                               range = range,
+                               pc.out = pc.out,
+                               label.qty = label.qty,
+                               span = span,
+                               annotations = annotations, norm = norm,
                                text.size = text.size,
+                               idfactor = idfactor,
+                               ylim = ylim,
                                na.rm = na.rm,
                                ...)
     } else {
       stop("Invalid 'unit.out' argument value: '", unit.out, "'")
     }
-    if ("title" %in% annotations) {
-      out.ggplot <- out.ggplot + labs(title = deparse(substitute(x)))
-    }
-    out.ggplot
+    out.ggplot +
+      ggtitle_spct(x = x,
+                   time.format = time.format,
+                   tz = tz,
+                   x.name = deparse(substitute(x)),
+                   annotations = annotations)
   }
 
+#' @rdname plot.response_spct
+#'
+#' @export
+#'
+plot.response_mspct <-
+  function(x, ..., range = NULL) {
+    if (!is.null(range)) {
+      x <- trim_wl(x, range = range, use.hinges = TRUE, fill = NULL)
+    }
+    z <- rbindspct(x)
+    plot(x = z, range = NULL, ...)
+  }
 
