@@ -49,12 +49,12 @@
 #'   \item{y.label}{ymean multiplied by \code{label.mult} and formatted
 #'   according to \code{label.fmt}}
 #'   \item{x}{w.band-midpoint}
-#'   \item{xmin}{w.band minimum}
-#'   \item{xmax}{w.band maximum}
-#'   \item{ymin}{data$y minimum}
-#'   \item{ymax}{data$y maximum}
-#'   \item{yint}{data$y integral for the range of \code{w.band}}
-#'   \item{xmean}{yint divided by wl_expanse(w.band)}
+#'   \item{wb.xmin}{w.band minimum}
+#'   \item{wb.xmax}{w.band maximum}
+#'   \item{wb.ymin}{data$y minimum}
+#'   \item{wb.ymax}{data$y maximum}
+#'   \item{wb.yint}{data$y integral for the range of \code{w.band}}
+#'   \item{wb.xmean}{yint divided by wl_expanse(w.band)}
 #'   \item{y}{ypos.fixed or top of data, adjusted by \code{ypos.mult}}
 #'   \item{wb.color}{color of the w.band}
 #'   \item{wb.name}{label of w.band}
@@ -66,11 +66,11 @@
 #' \describe{
 #'   \item{label}{..y.label..}
 #'   \item{x}{..x..}
-#'   \item{xmin}{..xmin..}
-#'   \item{xmax}{..xmax..}
+#'   \item{xmin}{..wb.xmin..}
+#'   \item{xmax}{..wb.xmax..}
 #'   \item{ymin}{0}
-#'   \item{ymax}{..ymean..}
-#'   \item{yintercept}{..ymean..}
+#'   \item{ymax}{..wb.ymean..}
+#'   \item{yintercept}{..wb.ymean..}
 #'   \item{fill}{..wb.color..}
 #' }
 #'
@@ -152,7 +152,7 @@ StatWbMean <-
                                             xpos.fixed,
                                             ypos.fixed) {
                      if (length(w.band) == 0) {
-                       w.band <- waveband(data$x)
+                       w.band <- waveband(data[["x"]])
                      }
                      if (is.any_spct(w.band) ||
                          (is.numeric(w.band) && length(na.omit(w.band)) >= 2)) {
@@ -162,7 +162,7 @@ StatWbMean <-
                        w.band <- list(w.band)
                      }
                      stopifnot(is.function(integral.fun))
-                     w.band <- trim_wl(w.band, data$x)
+                     w.band <- trim_wl(w.band, data[["x"]])
                      integ.df <- data.frame()
                      for (wb in w.band) {
                        if (is.numeric(wb)) { # user supplied a list of numeric vectors
@@ -170,48 +170,47 @@ StatWbMean <-
                        }
 
                        range <- range(wb)
-                       mydata <- trim_tails(data$x, data$y, use.hinges = TRUE,
+                       mydata <- trim_tails(data[["x"]], data[["y"]], use.hinges = TRUE,
                                             low.limit = range[1],
                                             high.limit = range[2],
                                             verbose = FALSE)
                        if (is_effective(wb)) {
                          warning("BSWFs not supported by summary: using wavelength range for ",
-                                 labels(wb)$label, "'.")
+                                 labels(wb)[["label"]], "'.")
                          wb <- waveband(wb)
                        }
-                       yint.tmp <- integral.fun(mydata$x, mydata$y)
+                       yint.tmp <- integral.fun(mydata[["x"]], mydata[["y"]])
                        ymean.tmp <- yint.tmp / wl_expanse(wb)
                        integ.df <- rbind(integ.df,
                                          data.frame(x = midpoint(wb),
-                                                    xmin = min(wb),
-                                                    xmax = max(wb),
-                                                    ymin = min(data$y),
-                                                    ymax = max(data$y),
-                                                    yint = yint.tmp,
-                                                    ymean = ymean.tmp,
+                                                    wb.xmin = min(wb),
+                                                    wb.xmax = max(wb),
+                                                    wb.ymin = min(data[["y"]]),
+                                                    wb.ymax = max(data[["y"]]),
+                                                    wb.yint = yint.tmp,
+                                                    wb.ymean = ymean.tmp,
                                                     wb.color = color_of(wb),
-                                                    wb.name = labels(wb)$label,
+                                                    wb.name = labels(wb)[["label"]],
                                                     BW.color = black_or_white(color_of(wb)))
                                          )
                      }
                      if (!is.null(xpos.fixed)) {
-                       integ.df$x <- xpos.fixed
+                       integ.df[["x"]] <- xpos.fixed
                      }
                      if (is.null(ypos.fixed)) {
-                       integ.df$y <- with(integ.df, ymin + (ymean - ymin) * ypos.mult)
+                       integ.df[["y"]] <- with(integ.df, wb.ymin + (wb.ymean - wb.ymin) * ypos.mult)
                      } else {
-                       integ.df$y <- ypos.fixed
+                       integ.df[["y"]] <- ypos.fixed
                      }
-                     integ.df$y.label <- sprintf(label.fmt, integ.df$ymean * label.mult)
-#                     print(integ.df)
+                     integ.df[["y.label"]] <- sprintf(label.fmt, integ.df[["wb.ymean"]] * label.mult)
                      integ.df
                    },
                    default_aes = ggplot2::aes(label = ..y.label..,
-                                              xmin = ..xmin..,
-                                              xmax = ..xmax..,
-                                              ymax = ..ymean..,
+                                              xmin = ..wb.xmin..,
+                                              xmax = ..wb.xmax..,
+                                              ymax = ..wb.ymean..,
                                               ymin = 0,
-                                              yintercept = ..ymean..,
+                                              yintercept = ..wb.ymean..,
                                               fill = ..wb.color..,
                                               color = ..BW.color..),
                    required_aes = c("x", "y")
